from __future__ import annotations

KELVIN = 273.15
MONTHS_PER_YEAR = 12
SEC_PER_DAY = 86400
MIN_PER_DAY = 1440
MGM2D_PER_WM2 = SEC_PER_DAY / 1e6  # 1 W m-2 = 0.0864 MJ m-2 day-1
MM_PER_IN = 25.4
MB_PER_KPA = 10
PERCENT = 100
RELATIVE_VARS = ['pr']
ABSOLUTE_VARS = ['tasmax', 'tasmin']
APHYSICAL_TEMP_HIGH = 353  # Kelvin
APHYSICAL_TEMP_LOW = 0
APHYSICAL_PRECIP_HIGH = 3000
APHYSICAL_PRECIP_LOW = 0
